@@ -4,6 +4,7 @@ from functools import wraps
 from motor.motor_asyncio import AsyncIOMotorCollection, AsyncIOMotorClient
 
 from .document_dict import DocumentDict
+from .document_array import DocumentArray
 
 LOG = logging.getLogger("mdocument")
 
@@ -101,6 +102,8 @@ class Document(metaclass=MetaDocument):
         try:
             if isinstance(self._document_[item], dict):
                 return DocumentDict(self._document_[item])
+            elif isinstance(self._document_[item], list):
+                return DocumentArray(self._document_[item])
             return self._document_[item]
         except KeyError:
             raise AttributeError(item)
